nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

AsCtrl

Struct AsCtrl 

#[repr(transparent)]
pub struct AsCtrl(pub u32);
Alpha Surface Control

Tuple Fields

0: u32

Implementations

Source

impl AsCtrl

pub const fn alpha_ctrl(&self) -> AlphaCtrl

Determines how the alpha value is constructed for this alpha surface

pub const fn set_alpha_ctrl(&mut self, val: AlphaCtrl)

Determines how the alpha value is constructed for this alpha surface

pub const fn enable_colorkey(&self) -> bool

Indicates that colorkey functionality is enabled for this alpha surface

pub const fn set_enable_colorkey(&mut self, val: bool)

Indicates that colorkey functionality is enabled for this alpha surface

pub const fn format(&self) -> AsCtrlFormat

Indicates the input buffer format for AS.

pub const fn set_format(&mut self, val: AsCtrlFormat)

Indicates the input buffer format for AS.

pub const fn alpha(&self) -> u8

Alpha modifier used when the ALPHA_MULTIPLY or ALPHA_OVERRIDE values are programmed in PXP_AS_CTRL[ALPHA_CTRL]

pub const fn set_alpha(&mut self, val: u8)

Alpha modifier used when the ALPHA_MULTIPLY or ALPHA_OVERRIDE values are programmed in PXP_AS_CTRL[ALPHA_CTRL]

pub const fn rop(&self) -> Rop

Indicates a raster operation to perform when enabled

pub const fn set_rop(&mut self, val: Rop)

Indicates a raster operation to perform when enabled

pub const fn alpha_invert(&self) -> AlphaInvert

Setting this bit to logic 0 will not alter the alpha value

pub const fn set_alpha_invert(&mut self, val: AlphaInvert)

Setting this bit to logic 0 will not alter the alpha value