#[repr(transparent)]pub struct CtrlSet(pub u32);Expand description
Control Register 0
Tuple Fields
0: u32Implementations
Sourceimpl CtrlSet
impl CtrlSet
Sourcepub const fn set_enable(&mut self, val: bool)
pub const fn set_enable(&mut self, val: bool)
Enables PXP operation with specified parameters
Sourcepub const fn irq_enable(&self) -> bool
pub const fn irq_enable(&self) -> bool
Interrupt enable When using the PXP_NEXT functionality to reprogram the PXP, the new value of this bit will be used and may therefore enable or disable an interrupt unintentionally
Sourcepub const fn set_irq_enable(&mut self, val: bool)
pub const fn set_irq_enable(&mut self, val: bool)
Interrupt enable When using the PXP_NEXT functionality to reprogram the PXP, the new value of this bit will be used and may therefore enable or disable an interrupt unintentionally
Sourcepub const fn next_irq_enable(&self) -> bool
pub const fn next_irq_enable(&self) -> bool
Next command interrupt enable
Sourcepub const fn set_next_irq_enable(&mut self, val: bool)
pub const fn set_next_irq_enable(&mut self, val: bool)
Next command interrupt enable
Sourcepub const fn enable_lcd_handshake(&self) -> bool
pub const fn enable_lcd_handshake(&self) -> bool
Enable handshake with LCD controller
Sourcepub const fn set_enable_lcd_handshake(&mut self, val: bool)
pub const fn set_enable_lcd_handshake(&mut self, val: bool)
Enable handshake with LCD controller
Sourcepub const fn rotate(&self) -> CtrlSetRotate
pub const fn rotate(&self) -> CtrlSetRotate
Indicates the clockwise rotation to be applied at the output buffer
Sourcepub const fn set_rotate(&mut self, val: CtrlSetRotate)
pub const fn set_rotate(&mut self, val: CtrlSetRotate)
Indicates the clockwise rotation to be applied at the output buffer
Sourcepub const fn hflip(&self) -> bool
pub const fn hflip(&self) -> bool
Indicates that the output buffer should be flipped horizontally (effect applied before rotation).
Sourcepub const fn set_hflip(&mut self, val: bool)
pub const fn set_hflip(&mut self, val: bool)
Indicates that the output buffer should be flipped horizontally (effect applied before rotation).
Sourcepub const fn vflip(&self) -> bool
pub const fn vflip(&self) -> bool
Indicates that the output buffer should be flipped vertically (effect applied before rotation).
Sourcepub const fn set_vflip(&mut self, val: bool)
pub const fn set_vflip(&mut self, val: bool)
Indicates that the output buffer should be flipped vertically (effect applied before rotation).
Sourcepub const fn rot_pos(&self) -> bool
pub const fn rot_pos(&self) -> bool
This bit controls where rotation will occur in the PXP datapath
Sourcepub const fn set_rot_pos(&mut self, val: bool)
pub const fn set_rot_pos(&mut self, val: bool)
This bit controls where rotation will occur in the PXP datapath
Sourcepub const fn block_size(&self) -> CtrlSetBlockSize
pub const fn block_size(&self) -> CtrlSetBlockSize
Select the block size to process.
Sourcepub const fn set_block_size(&mut self, val: CtrlSetBlockSize)
pub const fn set_block_size(&mut self, val: CtrlSetBlockSize)
Select the block size to process.
Sourcepub const fn en_repeat(&self) -> CtrlSetEnRepeat
pub const fn en_repeat(&self) -> CtrlSetEnRepeat
Enable the PXP to run continuously
Sourcepub const fn set_en_repeat(&mut self, val: CtrlSetEnRepeat)
pub const fn set_en_repeat(&mut self, val: CtrlSetEnRepeat)
Enable the PXP to run continuously
Sourcepub const fn clkgate(&self) -> CtrlSetClkgate
pub const fn clkgate(&self) -> CtrlSetClkgate
This bit must be set to zero for normal operation
Sourcepub const fn set_clkgate(&mut self, val: CtrlSetClkgate)
pub const fn set_clkgate(&mut self, val: CtrlSetClkgate)
This bit must be set to zero for normal operation
Sourcepub const fn sftrst(&self) -> CtrlSetSftrst
pub const fn sftrst(&self) -> CtrlSetSftrst
This bit can be turned on and then off to reset the PXP block to its default state.
Sourcepub const fn set_sftrst(&mut self, val: CtrlSetSftrst)
pub const fn set_sftrst(&mut self, val: CtrlSetSftrst)
This bit can be turned on and then off to reset the PXP block to its default state.