nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Next

Struct Next 

#[repr(transparent)]
pub struct Next(pub u32);
Next Frame Pointer

Tuple Fields

0: u32

Implementations

Source

impl Next

pub const fn enabled(&self) -> bool

Indicates that the “next frame” functionality has been enabled

pub const fn set_enabled(&mut self, val: bool)

Indicates that the “next frame” functionality has been enabled

pub const fn pointer(&self) -> u32

A pointer to a data structure containing register values to be used when processing the next frame

pub const fn set_pointer(&mut self, val: u32)

A pointer to a data structure containing register values to be used when processing the next frame