nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

OutAsLrc

Struct OutAsLrc 

#[repr(transparent)]
pub struct OutAsLrc(pub u32);
Alpha Surface Lower Right Coordinate

Tuple Fields

0: u32

Implementations

Source

impl OutAsLrc

pub const fn y(&self) -> u16

This field indicates the lower right Y-coordinate (in pixels) of the alpha surface in the output frame buffer

pub const fn set_y(&mut self, val: u16)

This field indicates the lower right Y-coordinate (in pixels) of the alpha surface in the output frame buffer

pub const fn x(&self) -> u16

This field indicates the lower right X-coordinate (in pixels) of the alpha surface (AS) in the output frame buffer

pub const fn set_x(&mut self, val: u16)

This field indicates the lower right X-coordinate (in pixels) of the alpha surface (AS) in the output frame buffer