#[repr(transparent)]pub struct OutAsUlc(pub u32);Expand description
Alpha Surface Upper Left Coordinate
Tuple Fields
0: u32Implementations
Sourceimpl OutAsUlc
impl OutAsUlc
Sourcepub const fn y(&self) -> u16
pub const fn y(&self) -> u16
This field indicates the upper left Y-coordinate (in pixels) of the alpha surface in the output frame buffer
Sourcepub const fn set_y(&mut self, val: u16)
pub const fn set_y(&mut self, val: u16)
This field indicates the upper left Y-coordinate (in pixels) of the alpha surface in the output frame buffer