nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

OutCtrl

Struct OutCtrl 

#[repr(transparent)]
pub struct OutCtrl(pub u32);
Output Buffer Control Register

Tuple Fields

0: u32

Implementations

Source

impl OutCtrl

pub const fn format(&self) -> OutCtrlFormat

Output framebuffer format

pub const fn set_format(&mut self, val: OutCtrlFormat)

Output framebuffer format

pub const fn interlaced_output(&self) -> OutCtrlInterlacedOutput

Determines how the PXP writes it’s output data

pub const fn set_interlaced_output(&mut self, val: OutCtrlInterlacedOutput)

Determines how the PXP writes it’s output data

pub const fn alpha_output(&self) -> OutCtrlAlphaOutput

Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]

pub const fn set_alpha_output(&mut self, val: OutCtrlAlphaOutput)

Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]

pub const fn alpha(&self) -> u8

When generating an output buffer with an alpha component, the value in this field will be used when enabled to override the alpha passed through the pixel data pipeline

pub const fn set_alpha(&mut self, val: u8)

When generating an output buffer with an alpha component, the value in this field will be used when enabled to override the alpha passed through the pixel data pipeline