#[repr(transparent)]pub struct OutCtrlClr(pub u32);Expand description
Output Buffer Control Register
Tuple Fields
0: u32Implementations
Sourceimpl OutCtrlClr
impl OutCtrlClr
Sourcepub const fn format(&self) -> OutCtrlClrFormat
pub const fn format(&self) -> OutCtrlClrFormat
Output framebuffer format
Sourcepub const fn set_format(&mut self, val: OutCtrlClrFormat)
pub const fn set_format(&mut self, val: OutCtrlClrFormat)
Output framebuffer format
Sourcepub const fn interlaced_output(&self) -> OutCtrlClrInterlacedOutput
pub const fn interlaced_output(&self) -> OutCtrlClrInterlacedOutput
Determines how the PXP writes it’s output data
Sourcepub const fn set_interlaced_output(&mut self, val: OutCtrlClrInterlacedOutput)
pub const fn set_interlaced_output(&mut self, val: OutCtrlClrInterlacedOutput)
Determines how the PXP writes it’s output data
Sourcepub const fn alpha_output(&self) -> OutCtrlClrAlphaOutput
pub const fn alpha_output(&self) -> OutCtrlClrAlphaOutput
Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]
Sourcepub const fn set_alpha_output(&mut self, val: OutCtrlClrAlphaOutput)
pub const fn set_alpha_output(&mut self, val: OutCtrlClrAlphaOutput)
Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]