nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

OutCtrlSet

Struct OutCtrlSet 

#[repr(transparent)]
pub struct OutCtrlSet(pub u32);
Output Buffer Control Register

Tuple Fields

0: u32

Implementations

Source

impl OutCtrlSet

pub const fn format(&self) -> OutCtrlSetFormat

Output framebuffer format

pub const fn set_format(&mut self, val: OutCtrlSetFormat)

Output framebuffer format

pub const fn interlaced_output(&self) -> OutCtrlSetInterlacedOutput

Determines how the PXP writes it’s output data

pub const fn set_interlaced_output(&mut self, val: OutCtrlSetInterlacedOutput)

Determines how the PXP writes it’s output data

pub const fn alpha_output(&self) -> OutCtrlSetAlphaOutput

Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]

pub const fn set_alpha_output(&mut self, val: OutCtrlSetAlphaOutput)

Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]

pub const fn alpha(&self) -> u8

When generating an output buffer with an alpha component, the value in this field will be used when enabled to override the alpha passed through the pixel data pipeline

pub const fn set_alpha(&mut self, val: u8)

When generating an output buffer with an alpha component, the value in this field will be used when enabled to override the alpha passed through the pixel data pipeline