nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

OutPitch

Struct OutPitch 

#[repr(transparent)]
pub struct OutPitch(pub u32);
Output Buffer Pitch

Tuple Fields

0: u32

Implementations

Source

impl OutPitch

pub const fn pitch(&self) -> u16

Indicates the number of bytes in memory between two vertically adjacent pixels.

pub const fn set_pitch(&mut self, val: u16)

Indicates the number of bytes in memory between two vertically adjacent pixels.