#[repr(transparent)]pub struct Power(pub u32);Expand description
PXP Power Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Power
impl Power
Sourcepub const fn rot_mem_lp_state(&self) -> RotMemLpState
pub const fn rot_mem_lp_state(&self) -> RotMemLpState
Select the low power state of the Rotation (ROT) memory.
Sourcepub const fn set_rot_mem_lp_state(&mut self, val: RotMemLpState)
pub const fn set_rot_mem_lp_state(&mut self, val: RotMemLpState)
Select the low power state of the Rotation (ROT) memory.