nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

PsBackground

Struct PsBackground 

#[repr(transparent)]
pub struct PsBackground(pub u32);
PS Background Color

Tuple Fields

0: u32

Implementations

Source

impl PsBackground

pub const fn color(&self) -> u32

Background color (in 24bpp format) for any pixels not within the buffer range specified by the PS ULC/LRC

pub const fn set_color(&mut self, val: u32)

Background color (in 24bpp format) for any pixels not within the buffer range specified by the PS ULC/LRC