nxp-pac

Crates

git

Versions

mimxrt1062

Flavors

Stat

Struct Stat 

#[repr(transparent)]
pub struct Stat(pub u32);
Status Register

Tuple Fields

0: u32

Implementations

Source

impl Stat

pub const fn irq(&self) -> StatIrq

Indicates current PXP interrupt status

pub const fn set_irq(&mut self, val: StatIrq)

Indicates current PXP interrupt status

pub const fn axi_write_error(&self) -> StatAxiWriteError

Indicates PXP encountered an AXI write error and processing has been terminated.

pub const fn set_axi_write_error(&mut self, val: StatAxiWriteError)

Indicates PXP encountered an AXI write error and processing has been terminated.

pub const fn axi_read_error(&self) -> StatAxiReadError

Indicates PXP encountered an AXI read error and processing has been terminated.

pub const fn set_axi_read_error(&mut self, val: StatAxiReadError)

Indicates PXP encountered an AXI read error and processing has been terminated.

pub const fn next_irq(&self) -> bool

Indicates that a command issued with the “Next Command” functionality has been issued and that a new command may be initiated with a write to the PXP_NEXT register

pub const fn set_next_irq(&mut self, val: bool)

Indicates that a command issued with the “Next Command” functionality has been issued and that a new command may be initiated with a write to the PXP_NEXT register

pub const fn axi_error_id(&self) -> u8

Indicates the AXI ID of the failing bus operation.

pub const fn set_axi_error_id(&mut self, val: u8)

Indicates the AXI ID of the failing bus operation.

pub const fn lut_dma_load_done_irq(&self) -> StatLutDmaLoadDoneIrq

Indicates that the LUT DMA transfer has completed.

pub const fn set_lut_dma_load_done_irq(&mut self, val: StatLutDmaLoadDoneIrq)

Indicates that the LUT DMA transfer has completed.

pub const fn blocky(&self) -> u8

Indicates the X coordinate of the block currently being rendered.

pub const fn set_blocky(&mut self, val: u8)

Indicates the X coordinate of the block currently being rendered.

pub const fn blockx(&self) -> u8

Indicates the X coordinate of the block currently being rendered.

pub const fn set_blockx(&mut self, val: u8)

Indicates the X coordinate of the block currently being rendered.