#[repr(transparent)]pub struct StatSet(pub u32);Expand description
Status Register
Tuple Fields
0: u32Implementations
Sourceimpl StatSet
impl StatSet
Sourcepub const fn irq(&self) -> StatSetIrq
pub const fn irq(&self) -> StatSetIrq
Indicates current PXP interrupt status
Sourcepub const fn set_irq(&mut self, val: StatSetIrq)
pub const fn set_irq(&mut self, val: StatSetIrq)
Indicates current PXP interrupt status
Sourcepub const fn axi_write_error(&self) -> StatSetAxiWriteError
pub const fn axi_write_error(&self) -> StatSetAxiWriteError
Indicates PXP encountered an AXI write error and processing has been terminated.
Sourcepub const fn set_axi_write_error(&mut self, val: StatSetAxiWriteError)
pub const fn set_axi_write_error(&mut self, val: StatSetAxiWriteError)
Indicates PXP encountered an AXI write error and processing has been terminated.
Sourcepub const fn axi_read_error(&self) -> StatSetAxiReadError
pub const fn axi_read_error(&self) -> StatSetAxiReadError
Indicates PXP encountered an AXI read error and processing has been terminated.
Sourcepub const fn set_axi_read_error(&mut self, val: StatSetAxiReadError)
pub const fn set_axi_read_error(&mut self, val: StatSetAxiReadError)
Indicates PXP encountered an AXI read error and processing has been terminated.
Sourcepub const fn next_irq(&self) -> bool
pub const fn next_irq(&self) -> bool
Indicates that a command issued with the “Next Command” functionality has been issued and that a new command may be initiated with a write to the PXP_NEXT register
Sourcepub const fn set_next_irq(&mut self, val: bool)
pub const fn set_next_irq(&mut self, val: bool)
Indicates that a command issued with the “Next Command” functionality has been issued and that a new command may be initiated with a write to the PXP_NEXT register
Sourcepub const fn axi_error_id(&self) -> u8
pub const fn axi_error_id(&self) -> u8
Indicates the AXI ID of the failing bus operation.
Sourcepub const fn set_axi_error_id(&mut self, val: u8)
pub const fn set_axi_error_id(&mut self, val: u8)
Indicates the AXI ID of the failing bus operation.
Sourcepub const fn lut_dma_load_done_irq(&self) -> StatSetLutDmaLoadDoneIrq
pub const fn lut_dma_load_done_irq(&self) -> StatSetLutDmaLoadDoneIrq
Indicates that the LUT DMA transfer has completed.
Sourcepub const fn set_lut_dma_load_done_irq(&mut self, val: StatSetLutDmaLoadDoneIrq)
pub const fn set_lut_dma_load_done_irq(&mut self, val: StatSetLutDmaLoadDoneIrq)
Indicates that the LUT DMA transfer has completed.
Sourcepub const fn blocky(&self) -> u8
pub const fn blocky(&self) -> u8
Indicates the X coordinate of the block currently being rendered.
Sourcepub const fn set_blocky(&mut self, val: u8)
pub const fn set_blocky(&mut self, val: u8)
Indicates the X coordinate of the block currently being rendered.
Sourcepub const fn blockx(&self) -> u8
pub const fn blockx(&self) -> u8
Indicates the X coordinate of the block currently being rendered.
Sourcepub const fn set_blockx(&mut self, val: u8)
pub const fn set_blockx(&mut self, val: u8)
Indicates the X coordinate of the block currently being rendered.