#[repr(transparent)]pub struct Next(pub u32);Expand description
Next Frame Pointer
Tuple Fields
0: u32Implementations
Sourceimpl Next
impl Next
Sourcepub const fn enabled(&self) -> bool
pub const fn enabled(&self) -> bool
Indicates that the “next frame” functionality has been enabled
Sourcepub const fn set_enabled(&mut self, val: bool)
pub const fn set_enabled(&mut self, val: bool)
Indicates that the “next frame” functionality has been enabled
Sourcepub const fn pointer(&self) -> u32
pub const fn pointer(&self) -> u32
A pointer to a data structure containing register values to be used when processing the next frame
Sourcepub const fn set_pointer(&mut self, val: u32)
pub const fn set_pointer(&mut self, val: u32)
A pointer to a data structure containing register values to be used when processing the next frame