#[repr(transparent)]pub struct OutAsLrc(pub u32);Expand description
Alpha Surface Lower Right Coordinate
Tuple Fields
0: u32Implementations
Sourceimpl OutAsLrc
impl OutAsLrc
Sourcepub const fn y(&self) -> u16
pub const fn y(&self) -> u16
This field indicates the lower right Y-coordinate (in pixels) of the alpha surface in the output frame buffer
Sourcepub const fn set_y(&mut self, val: u16)
pub const fn set_y(&mut self, val: u16)
This field indicates the lower right Y-coordinate (in pixels) of the alpha surface in the output frame buffer