#[repr(transparent)]pub struct OutCtrlSet(pub u32);Expand description
Output Buffer Control Register
Tuple Fields
0: u32Implementations
Sourceimpl OutCtrlSet
impl OutCtrlSet
Sourcepub const fn format(&self) -> OutCtrlSetFormat
pub const fn format(&self) -> OutCtrlSetFormat
Output framebuffer format
Sourcepub const fn set_format(&mut self, val: OutCtrlSetFormat)
pub const fn set_format(&mut self, val: OutCtrlSetFormat)
Output framebuffer format
Sourcepub const fn interlaced_output(&self) -> OutCtrlSetInterlacedOutput
pub const fn interlaced_output(&self) -> OutCtrlSetInterlacedOutput
Determines how the PXP writes it’s output data
Sourcepub const fn set_interlaced_output(&mut self, val: OutCtrlSetInterlacedOutput)
pub const fn set_interlaced_output(&mut self, val: OutCtrlSetInterlacedOutput)
Determines how the PXP writes it’s output data
Sourcepub const fn alpha_output(&self) -> OutCtrlSetAlphaOutput
pub const fn alpha_output(&self) -> OutCtrlSetAlphaOutput
Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]
Sourcepub const fn set_alpha_output(&mut self, val: OutCtrlSetAlphaOutput)
pub const fn set_alpha_output(&mut self, val: OutCtrlSetAlphaOutput)
Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]