#[repr(transparent)]pub struct OutCtrlTog(pub u32);Expand description
Output Buffer Control Register
Tuple Fields
0: u32Implementations
Sourceimpl OutCtrlTog
impl OutCtrlTog
Sourcepub const fn format(&self) -> OutCtrlTogFormat
pub const fn format(&self) -> OutCtrlTogFormat
Output framebuffer format
Sourcepub const fn set_format(&mut self, val: OutCtrlTogFormat)
pub const fn set_format(&mut self, val: OutCtrlTogFormat)
Output framebuffer format
Sourcepub const fn interlaced_output(&self) -> OutCtrlTogInterlacedOutput
pub const fn interlaced_output(&self) -> OutCtrlTogInterlacedOutput
Determines how the PXP writes it’s output data
Sourcepub const fn set_interlaced_output(&mut self, val: OutCtrlTogInterlacedOutput)
pub const fn set_interlaced_output(&mut self, val: OutCtrlTogInterlacedOutput)
Determines how the PXP writes it’s output data
Sourcepub const fn alpha_output(&self) -> OutCtrlTogAlphaOutput
pub const fn alpha_output(&self) -> OutCtrlTogAlphaOutput
Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]
Sourcepub const fn set_alpha_output(&mut self, val: OutCtrlTogAlphaOutput)
pub const fn set_alpha_output(&mut self, val: OutCtrlTogAlphaOutput)
Indicates that alpha component in output buffer pixels should be overwritten by PXP_OUT_CTRL[ALPHA]